@@ -32,7 +32,7 @@ mult.model = inla(y ~ -1 + intercept + x,
          data = data.frame(y, x, Ntrials, intercept = rep(1, n)),
          family = "binomial", Ntrials = Ntrials,
          control.predictor = list(hyper = list(prec = list(initial = lprec))),
-         control.inla = list(tolerance = 1E-12))
+         control.inla = list(int.strategy="eb"))
 
 
 ## -------------------------------------------------------------------
@@ -59,7 +59,7 @@ pois.model = inla(Y ~ -1
           family="poisson",
           data = data.frame(Y, xx, phi , intercept), 
           control.predictor = list(hyper = list(prec = list(initial = lprec))), 
-          control.inla = list(tolerance = 1E-12))
+          control.inla = list(int.strategy="eb"))
 
 
 ## -------------------------------------------------------------------
@@ -155,7 +155,8 @@ formula = Y ~ -1 + X + W.A + W.B + W.C +
 
 ## -------------------------------------------------------------------
 Data = Data.structure(df)
-model = inla(formula, data = Data, family = 'Poisson')
+model = inla(formula, data = Data, family = 'Poisson',
+	control.inla=list(int.strategy="eb"))
 
 ## -------------------------------------------------------------------
 result = rbind(model$summary.fixed[1:5], model$summary.random$alt.idx[2:6])
@@ -209,7 +210,8 @@ formula.rand1 = Y ~ -1 + X + W.A + W.B + W.C +
   f(rand.idx, model = "iid")  #random effect
 
 ## -------------------------------------------------------------------
-model.rand1 = inla(formula.rand1, data = Data.rand1, family = 'Poisson')
+model.rand1 = inla(formula.rand1, data = Data.rand1, family ='Poisson',
+	control.inla=list(int.strategy="eb"))
 result.rand1 = rbind(model.rand1$summary.fixed[1:5])
 result.rand1 = cbind(result.rand1, true = param[1:4])
 row.names(result.rand1) = c("beta","delta.A","delta.B","delta.C")
@@ -251,7 +253,8 @@ formula.rw1 = Y ~ -1 + X + W.A + W.B + W.C +
   f(alt.idx, Z, fixed = T, constr = T) + 
   f(rw1.idx, model = "rw1")  #random walk of order 1
 
-model.rw1 = inla(formula.rw1, family = 'poisson', data = Data.rw1)
+model.rw1 = inla(formula.rw1, family = 'poisson', data = Data.rw1,
+	control.inla=list(int.strategy="eb"))
 
 ## ----fig.cap=c("Estimate of a random walk, the black line represents the true one and the red line the estimate"), echo=FALSE, fig.height=4----
 plot(random.walk1 - mean(random.walk1), type = 'l', 
@@ -354,7 +357,8 @@ formula.spatial = Y ~ -1 + X + W.A + W.B + W.C +
   f(rand.eff.idx, model = 'besag', graph = ADJ) #spatial random effect
 
 # Fit the model
-model.spatial = inla(formula.spatial, family = "poisson", data = Data.spatial)
+model.spatial = inla(formula.spatial, family = "poisson", data = Data.spatial,
+	control.inla=list(int.strategy="eb"))
 
 # Check the results
 result.spatial = cbind(model.spatial$summary.fixed[3:5], true = param[1:4])
@@ -539,7 +543,8 @@ head(Data)
 formula = Y ~ -1 + price + feat + alpha.idx +
   f(phi, initial = -10, fixed = T) 
 
-model = inla(formula, data = Data, family = 'Poisson') 
+model = inla(formula, data = Data, family = 'Poisson',
+	control.inla=list(int.strategy="eb"))
 
 ## -------------------------------------------------------------------
 results = model$summary.fixed[,1:5]
@@ -553,7 +558,8 @@ formula.price = Y ~ -1 + feat + alpha.idx +
   f(price.class, model = "rw1") + 
   f(phi, initial = -10, fixed = T) 
 
-model.price = inla(formula.price, data = Data, family = 'Poisson') 
+model.price = inla(formula.price, data = Data, family = 'Poisson',
+	control.inla=list(int.strategy="eb"))
 
 res = model.price$summary.fixed[,1:5]
 rownames(res) = c('feat', 'dannon','hiland','weight','yoplait')
@@ -598,7 +604,8 @@ formula.feat = Y ~ -1 + price + feat.yoplait + feat.dannon +
   f(phi, initial = -10, fixed = T)  
   
 
-model.feat = inla(formula.feat, data = Data, family = 'Poisson') 
+model.feat = inla(formula.feat, data = Data, family = 'Poisson',
+	control.inla=list(int.strategy="eb"))
 
 ## -------------------------------------------------------------------
 model.feat$summary.fixed[2:5, 1:5]
